@@ -21,7 +21,7 @@ def LFI():
 
         if response == 200:
             print(Fore.GREEN + "[HIGH] " + Style.RESET_ALL + "Potential LFI vulnerability found: " + path_of_url)
-            os.system('sudo touch LFI_vulnerable_urls.txt')
+            os.system('touch LFI_vulnerable_urls.txt')
             file = open('LFI_vulnerable_urls.txt', 'a')
             file.write(path_of_url)
             file.write('\n')
